@@ -24,7 +24,7 @@ use warnings;
 no warnings;
 use vars qw($VERSION);
 
-$VERSION = '2.123_04';
+$VERSION = '2.124_01';
 
 use Carp qw(carp croak);
 use File::Basename qw(dirname);
@@ -83,8 +83,7 @@ Do you want debugging output? Set this to a true value
 =item CPAN_PASS
 
 Your CPAN password. If you don't set this and you want to upload to
-PAUSE, you should be prompted for it. Failing that, the module tries
-to upload anonymously but cannot claim the file for you.
+PAUSE, you should be prompted for it.
 
 =back
 
@@ -196,6 +195,7 @@ sub _set_defaults {
 			debug          => $ENV{RELEASE_DEBUG} || 0,
 			local_file     => undef,
 			remote_file    => undef,
+			input_fh       => *STDIN{IO},
 			output_fh      => *STDOUT{IO},
 			debug_fh       => *STDERR{IO},
 			null_fh        => IO::Null->new(),
@@ -250,10 +250,6 @@ sub _process_configuration {
 	# Figure out options
 	$self->{cpan} = $self->config->cpan_user eq '<none>' ? 0 : 1;
 
-	$self->{passive_ftp} =
-		($self->config->passive_ftp && $self->config->passive_ftp =~ /^y(es)?/) ? 1 : 0;
-
-
 	{
 	my @pairs = (
 		[ qw(Makefile.PL makefile_PL) ],
@@ -560,6 +556,16 @@ sub reset_perls {
 	}
 
 
+=item input_fh
+
+Return the value of input_fh.
+
+=cut
+
+sub input_fh {
+    return $_[0]->{input_fh};
+}
+
 =item output_fh
 
 If quiet is off, return the value of output_fh. If output_fh is not
@@ -1197,7 +1203,7 @@ you may well want to overload it.
 =cut
 
 sub get_changes {
-	open my $fh, '<:utf8', 'Changes' or return '';
+	open my $fh, '<:encoding(UTF-8)', 'Changes' or return '';
 
 	my $data = <$fh>;  # get first line
 
@@ -1209,6 +1215,23 @@ sub get_changes {
 	return $data;
 	}
 
+=item show_recent_contributors()
+
+Show recent contributors before creating/extending Changes.
+
+This output relies upon the method C<get_recent_contributors()> having been
+implemented in the relevant mixin for your version control system.
+
+=cut
+
+sub show_recent_contributors {
+	my $self = shift;
+	return unless $self->can( 'get_recent_contributors' );
+	my @contributors = $self->get_recent_contributors;
+	$self->_print("Contributors since last release:\n") if @contributors;
+	$self->_print( "\t", $_, "\n" ) for @contributors;
+	}
+
 =item get_release_date()
 
 Return a string representing the current date and time (in UTC) in the
@@ -1220,7 +1243,6 @@ Changes file.
 sub get_release_date {
 	my $self = shift;
 	my $dt = DateTime->now(time_zone => 'UTC');
-
 	return $dt->datetime . 'Z';
 	}
 
@@ -1290,7 +1312,17 @@ sub get_env_var {
 	return $pass if defined( $pass ) && length( $pass );
 
 	$self->_print( "$field is not set.  Enter it now: " );
-	$pass = <>;
+	if ($field eq 'CPAN_PASS') {
+		# don't echo passwords to the screen
+		require Term::ReadKey;
+		local $| = 1;
+		Term::ReadKey::ReadMode('noecho');
+		$pass = $self->_slurp;
+		Term::ReadKey::ReadMode('restore');
+	}
+	else {
+		$pass = $self->_slurp;
+	}
 	chomp $pass;
 
 	return $pass if defined( $pass ) && length( $pass );
@@ -1313,6 +1345,17 @@ output_fh to a null filehandle, output goes nowhere.
 
 sub _print { print { $_[0]->output_fh } @_[1..$#_] }
 
+=item _slurp
+
+Read a line from whatever is in input_fh and return it.
+
+=cut
+
+sub _slurp {
+    my $fh = $_[0]->input_fh;
+    return <$fh>;
+}
+
 =item _dashes()
 
 Use this for a string representing a line in the output. Since it's a
@@ -1384,7 +1427,7 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2002-2017, brian d foy C<< <bdfoy@cpan.org> >>. All rights reserved.
+Copyright © 2007-2018, brian d foy C<< <bdfoy@cpan.org> >>. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the Artistic License 2.0.
