@@ -7,7 +7,7 @@ use vars qw($VERSION);
 
 our @EXPORT = qw( check_prereqs _get_prereq_ignore_list );
 
-$VERSION = '2.123_04';
+$VERSION = '2.124_01';
 
 =encoding utf8
 
@@ -39,12 +39,12 @@ my %Prereq_modules = (
 	'' => 'Test::Prereq',
 	'Makefile.PL' => 'Test::Prereq',
 	'Build.PL' => 'Test::Prereq::Build',
-);
+	);
 
 sub check_prereqs
 	{
 	my $prereqs_type = $_[0]->config->makefile_PL;
-	my $test_prereqs = $Prereq_modules{$prereqs_type} || 'Test::Prereq';
+	my $test_prereqs = $Prereq_modules{$prereqs_type // ''} || 'Test::Prereq';
 
 	eval "require $test_prereqs; 1 " or
 		$_[0]->_die( "You need $test_prereqs to check prereqs" );
@@ -88,7 +88,7 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2007-2017, brian d foy C<< <bdfoy@cpan.org> >>. All rights reserved.
+Copyright © 2007-2018, brian d foy C<< <bdfoy@cpan.org> >>. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the Artistic License 2.0.
